@@ -1,12 +1,13 @@
 from os import getenv
-from typing import Any, get_type_hints
+from typing import Any, Iterable
 
 from datek_app_utils.env_config.errors import InstantiationForbiddenError
 
 
 class Variable:
-    def __init__(self, type_: type = str):
+    def __init__(self, type_: type = str, default_value=...):
         self._type = type_
+        self._default_value = default_value
 
     def __set_name__(self, owner, name):
         self._name = name
@@ -14,6 +15,10 @@ class Variable:
     def __get__(self, obj, type_=None):
         return self.value
 
+    @property
+    def default_value(self) -> Any:
+        return self._default_value
+
     @property
     def name(self):
         return self._name
@@ -24,23 +29,28 @@ class Variable:
 
     @property
     def value(self) -> Any:
-        value = getenv(self._name)
-        if value is None:
-            return None
+        if (value := getenv(self._name)) is not None:
+            return self._type(value)
 
-        return self._type(value)
+        if self._default_value is not ...:
+            return self._default_value
 
 
 class ConfigMeta(type):
     def __new__(mcs, name: str, bases: tuple, namespace: dict):
-        temporary_class = type(f"_{name}", (), namespace)
-        for class_ in bases + (temporary_class,):
-            for key, value in get_type_hints(class_).items():
-                namespace[key] = Variable(value)
+        for key, type_ in namespace.get("__annotations__", {}).items():
+            namespace[key] = Variable(type_, namespace.get(key, ...))
+
+        for base in bases:
+            if not isinstance(base, ConfigMeta):
+                continue
+
+            for variable in base:
+                namespace[variable.name] = variable
 
         return super().__new__(mcs, name, bases, namespace)
 
-    def __iter__(cls):
+    def __iter__(cls) -> Iterable[Variable]:
         return (value for value in cls.__dict__.values() if isinstance(value, Variable))
 
 
